@@ -164,7 +164,7 @@ class ForwardManyToOneDescriptor(object):
                 rel_obj = None
             else:
                 qs = self.get_queryset(instance=instance)
-                qs = qs.filter(**self.field.get_reverse_related_filter(instance))
+                qs = qs.filter(self.field.get_reverse_related_filter(instance))
                 # Assuming the database enforces foreign keys, this won't fail.
                 rel_obj = qs.get()
                 # If this is a one-to-one relation, set the reverse accessor
@@ -243,7 +243,7 @@ class ForwardManyToOneDescriptor(object):
             for lh_field, rh_field in self.field.related_fields:
                 setattr(instance, lh_field.attname, getattr(value, rh_field.attname))
 
-        # Set the related instance cache used by __get__ to avoid a SQL query
+        # Set the related instance cache used by __get__ to avoid an SQL query
         # when accessing the attribute we just set.
         setattr(instance, self.cache_name, value)
 
@@ -416,7 +416,7 @@ class ReverseOneToOneDescriptor(object):
             for index, field in enumerate(self.related.field.local_related_fields):
                 setattr(value, field.attname, related_pk[index])
 
-            # Set the related instance cache used by __get__ to avoid a SQL query
+            # Set the related instance cache used by __get__ to avoid an SQL query
             # when accessing the attribute we just set.
             setattr(instance, self.cache_name, value)
 
